
import torch
import torch.nn as nn
import torch.nn.functional as func


criterion = nn.CrossEntropyLoss()

class nercLSTM(nn.Module):
   def __init__(self, codes) :
      super(nercLSTM, self).__init__()

      n_words = codes.get_n_words()
      n_sufs = codes.get_n_sufs()
      n_labels = codes.get_n_labels()
      
      embW_sz = 100
      embS_sz = 50
      self.embW = nn.Embedding(n_words, embW_sz)
      self.embS = nn.Embedding(n_sufs, embS_sz)      
      self.dropW = nn.Dropout(0.1)
      self.dropS = nn.Dropout(0.1)
      
      lstm_in_sz = embW_sz + embS_sz
      lstm_out_sz = 200
      self.lstm = nn.LSTM(lstm_in_sz, lstm_out_sz, bidirectional=True, batch_first=True)
      self.out = nn.Linear(2*lstm_out_sz, n_labels)


   def forward(self, w, s):
      x = self.embW(w)
      y = self.embS(s)
      x = self.dropW(x)
      y = self.dropS(y)

      x = torch.cat((x, y), dim=2)
      x = self.lstm(x)[0]              
      x = self.out(x)
      return x
   
   


